import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '首页', icon: 'dashboard' }
    }]
  },

  {
    path: '/gameManage',
    component: Layout,
    name: '游戏管理',
    meta: { title: '游戏管理', icon: 'form' },
    children: [
      {
        path: 'gameManage',
        name: '游戏列表',
        component: () => import('@/views/gameManage/index'),
        meta: { title: '游戏列表', icon: 'game' }
      },
      {
        hidden: true,
        path: 'gameManage/edit',
        name: 'gameEdit',
        component: () => import('@/views/gameManage/edit'),
        meta: { title: '编辑游戏', icon: 'form' }
      }
    ]
  },

  // 微信配置

  {
    path: '/WeChatConfig',
    component: Layout,
    meta: { title: '微信配置', icon: 'form' },
    children: [
      {
        path: 'WeChatConfig',
        name: 'WeChatConfig',
        component: () => import('@/views/WeChatConfig/index'),
        meta: { title: '微信配置', icon: 'wx' }
      },
      {
        hidden: true,
        path: 'WeChatConfig/Edit',
        name: '配置编辑',
        component: () => import('@/views/WeChatConfig/Edit'),
        meta: { title: '配置编辑', icon: 'form' }
      }
    ]
  },

  // 应用管理

  {
    path: '/AppController',
    component: Layout,
    meta: { title: '应用管理', icon: 'form' },
    children: [
      {
        path: 'AppController',
        name: '',
        component: () => import('@/views/AppController/index'),
        meta: { title: '应用管理', icon: 'appconfig' }
      }
    ]
  },

  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  {
    path: 'external-link',
    component: Layout,
    children: [
      {
        path: 'https://panjiachen.github.io/vue-element-admin-site/#/',
        meta: { title: 'External Link', icon: 'link' }
      }
    ]
  },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
